#include <sourcemod>

Handle g_iTimer[MAXPLAYERS+1];

public void OnPluginStart()
{
	HookEvent("round_start", 			Event_RoundStart, 		EventHookMode_PostNoCopy);
	HookEvent("round_end", 				Event_RoundEnd, 		EventHookMode_PostNoCopy);
	
	RegConsoleCmd("sm_timer", CmdTestTimer, "Starts timer for testing")
}

Action CmdTestTimer(int client, int args)
{
	// stop timer if it was already running
	// this will also set the variable to zero
	delete g_iTimer[client];
	PrintToChatAll("timer = %i", g_iTimer[client]);
	// starts repeatable timer
	// pass reference number of client, so we can ensure it is not replaced when timer will actually fire
	g_iTimer[client] = CreateTimer(15.0, Timer_Sample, GetClientUserId(client), TIMER_REPEAT);
}

public void Event_RoundStart(Event event, const char[] name, bool dontBroadcast)
{
	for ( int i = 1; i <= MaxClients; i++ )
	{
		if ( IsClientInGame(i) )
		{
			// start single per-client timer
			delete g_iTimer[i];
			g_iTimer[i] = CreateTimer(15.0, Timer_Sample, GetClientUserId(i), TIMER_REPEAT);
		}
	}
}

public void OnClientDisconnect(int client)
{
	// ensure, you kill timer when player disconnects
	delete g_iTimer[client];
}

void Reset()
{
	for ( int i = 0; i <= MaxClients; i++ )
	{
		delete g_iTimer[i];	// stops timer for each player
	}
}

public void Event_RoundEnd(Event event, const char[] name, bool dontBroadcast)
{
	Reset();
}

public void OnMapEnd() // required, because ForceChangeLevel doesn't cause "round_end" event
{
	Reset();
}

public Action Timer_Sample(Handle timer, int UserId)
{
	// check is it the same client
	int client = GetClientOfUserId(UserId);
	
	// ensure it is valid
	if ( client && IsClientInGame(client) )
	{
		// do something
		// ...
		PrintToChat(client, "tick");
		return Plugin_Continue;
		
		/* 	or, if you want to Stop timer,
			don't forget to 'null' timer firstly:
		
		g_iTimer[client] = null;
		return Plugin_Stop;
		*/
	}
	// here you can't null timer, because you don't know correct client index for accessing handle's variable,
	// so OnClientDisconnect() forward is used instead
	return Plugin_Stop;
}